/**
 * Copyright (c) 2014-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.api.pref;

import java.util.Map;

import org.ow2.petals.cli.api.connection.ConnectionParameters;
import org.ow2.petals.cli.api.pref.exception.MissingDefaultPreferenceFileException;
import org.ow2.petals.cli.api.pref.exception.PreferenceFileNotFoundException;

/**
 * Interface managing preferences
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public interface Preferences {
    
    /**
     * Returns the connection parameters associated to the default alias
     * 
     * @return The default connection parameters. Can be <code>null</code>
     */
    public ConnectionParameters getDefaultConnectionParameters();

    /**
     * 
     * @return The connection parameters per alias
     */
    public Map<String, ConnectionParameters> getPreferenceConnectionParameters();

    /**
     * Entry point of the preference parameter initialization.
     * 
     * @throws MissingDefaultPreferenceFileException
     *             The default preference file is missing
     * @throws PreferenceFileNotFoundException
     *             The preference file was not found
     * @throws PreferenceFileException
     *             An error occurs reading the preference file
     */
    public void intializePreferenceParameters() throws MissingDefaultPreferenceFileException,
            PreferenceFileNotFoundException, PreferenceFileException;
}
